@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::Old::Module;
 {
-  $App::Magpie::Action::Old::Module::VERSION = '1.122720';
+  $App::Magpie::Action::Old::Module::VERSION = '1.122721';
 }
 # ABSTRACT: module that has a newer version available
 
@@ -86,10 +86,8 @@ sub category {
     my @pkgs   = $self->packages;
     my $iscore = $self->is_core;
 
-    return "unparsable" if $self->oldver eq "Unparsable";
-
     if ( exists $SKIPMOD{ $self->name } ) {
-        return "ignored" if not defined $SKIPMOD{ $self->name };
+        return "ignored" if $SKIPMOD{ $self->name } eq "";
         return "ignored" if $self->newver eq $SKIPMOD{ $self->name };
     }
 
@@ -104,7 +102,8 @@ sub category {
     return "orphan"  if scalar(@pkgs) == 0;
     return "strange" if scalar(@pkgs) >= 2;
     # scalar(@pkgs) == 1;
-    return "ignored" if exists $SKIPPKG{ $pkgs[0]->name };
+    return "ignored"    if exists $SKIPPKG{ $pkgs[0]->name };
+    return "unparsable" if $self->oldver eq "Unparsable";
     return "normal";
 }
 
@@ -122,7 +121,7 @@ App::Magpie::Action::Old::Module - module that has a newer version available
 
 =head1 VERSION
 
-version 1.122720
+version 1.122721
 
 =head1 DESCRIPTION
 
